# CHANGELOG



## v0.1.0 (2024-05-12)

### Feature

* feat: bump version ([`20b01ef`](https://github.com/dtch1997/smol-sae/commit/20b01ef4895d18de91050d2a675d9d547cc269c1))


## v0.0.1 (2024-05-11)

### Chore

* chore: fix lint ([`ff889ef`](https://github.com/dtch1997/smol-sae/commit/ff889efa8950c573a56de266d786bbc4ecbaeca8))

* chore: add badges ([`6d07935`](https://github.com/dtch1997/smol-sae/commit/6d079355c7195b3dfc9d1fac5e70139641cee0ca))

### Fix

* fix: normalization dim, param names ([`f094f39`](https://github.com/dtch1997/smol-sae/commit/f094f39a64aa3bb670ceac496eb9d180e4120a38))

* fix: broken imports ([`b696a48`](https://github.com/dtch1997/smol-sae/commit/b696a4860182091daba4b1fe6b58655eea9e9ba7))


## v0.0.0 (2024-05-09)

### Chore

* chore: readme ([`3791ffb`](https://github.com/dtch1997/smol-sae/commit/3791ffbda349668d8f81256c96c9963a2f4e5de5))

* chore: add examples, test for vanilla SAE ([`777f8de`](https://github.com/dtch1997/smol-sae/commit/777f8deeb6ceafae767f895ace794e165cd243e8))

### Unknown

* remove pyright ([`11d27d4`](https://github.com/dtch1997/smol-sae/commit/11d27d4eb9387656a4c08b504e859d3b56a0325c))

* fix lint ([`e655967`](https://github.com/dtch1997/smol-sae/commit/e655967bfb84503272b7d4d01087502412840be8))

* test patch loss ([`228a192`](https://github.com/dtch1997/smol-sae/commit/228a192707f328ee7756189e7f8e0247cec6f79b))

* add test for VanillaSAE ([`b85fda4`](https://github.com/dtch1997/smol-sae/commit/b85fda41a7648acb4388c9fa933368b022c3c6bb))

* add code to train small SAE ([`d7cb2f9`](https://github.com/dtch1997/smol-sae/commit/d7cb2f92b73c8ac6e20abfc5ea3c3913748f0039))

* fix style ([`39dd961`](https://github.com/dtch1997/smol-sae/commit/39dd9618b6fc33b809db79f0b762c302959e9e99))

* move files to package dir ([`e606dd4`](https://github.com/dtch1997/smol-sae/commit/e606dd4ad6e0ceab996a87d97bb47d011121506b))

* add infra ([`7c94b69`](https://github.com/dtch1997/smol-sae/commit/7c94b69612496fdf4cfd577925e4249c5b75dc86))

* Create README.md ([`6261c37`](https://github.com/dtch1997/smol-sae/commit/6261c37ff83f5b6714079e300c3fbccee15dea93))

* fixed imports ([`2ea8bb2`](https://github.com/dtch1997/smol-sae/commit/2ea8bb2ae072e7d93a60d8c0c0851dea49c6f310))

* first commit ([`d22c220`](https://github.com/dtch1997/smol-sae/commit/d22c220bcea9c3886e6f128fe41b3f16aea83ea5))
